import streamlit as st
from __init__ import st_screen_data
# from st_screen_stats import st_screen_data


st.subheader("Component with constant args")

num_clicks = st_screen_data()
st.write(num_clicks)


if "count_" not in st.session_state:
    st.session_state["count_"] = 0

st.session_state["count_"] += 1
st.write(st.session_state["count_"])





import os
import streamlit.components.v1 as components

_RELEASE = True

if not _RELEASE:
    _st_screen_data = components.declare_component(

        "st_screen_data",

        url="http://localhost:3001",
    )
else:
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _st_screen_data = components.declare_component("st_screen_data", path=build_dir)


def st_screen_data(setTime=None, default=None, key=None):
    """
    Component to recieve screen stats to help you build a more responsive app.
    - setTime: this dictates period pause until data is received after resize. Default is 1000 (1 second)
    - default: default value for component
    - key: unique identifier for streamlit (will be recognised by streamlit session state)
    """
    component_value = _st_screen_data(setTime=setTime, key=key, default=default)

    return component_value




